@@ -1,9 +1,10 @@
+use strict ;
+
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
 
 ; package CGI::Builder::Const
 
-; use strict
 
 ; my $h
 ; our (@phase, $END)
@@ -38,6 +39,8 @@
 
 __END__
 
+=pod
+
 =head1 NAME
 
 CGI::Builder::Const - Imports constants
@@ -76,3 +79,5 @@ See L<CGI::Builder/"SUPPORT">.
  2004 by Domizio Demichelis.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as perl itself.
+
+=cut
